==> haskell-crypto-random-0.0.9-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-crypto-random/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-1a34631cfa2fcb67c67a6201143b0147
key: crypt_7BiCOK9v78J36YeClUc9KE
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Random Crypto.Random.Test Crypto.Random.API
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-random-0.0.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-7BiCOK9v78J36YeClUc9KE
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    securemem-0.1.9-b2776257967087e0982593cb67cce3c9
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-crypto-random/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-bdb6a693941c8915b178724d04100946
key: crypt_H63HZzJIH0n8WGy1D8JZt3
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Random Crypto.Random.Test Crypto.Random.API
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-random-0.0.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-H63HZzJIH0n8WGy1D8JZt3
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    securemem-0.1.9-01ec912d1ae68740f3ee3b7079e4f920
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
